@@ -9,7 +9,8 @@ __all__ = [
     "read_image",
     "Otsu_tresholding",
     "read_plu_topography",
-    "fill_gap"
+    "fill_gap",
+    "top_hat_flattening"
 ]
 
 
@@ -27,6 +28,7 @@ def stripe_removal(ima, **kwargs):
                   kwargs["wname"] wname of the wavelet (default db15)
                   kwargs["decNum_h"] order of decimation
                   kwargs["sigma_wl_h"] sigma_wl_h
+                  kwargs["order"] order of the polynome if mode=poly
     Returns:
         iama: corrected image
     """
@@ -91,6 +93,7 @@ def stripe_del(ima, mode, order=3):
     Returns
         ima (nparray): corrected image
     '''
+    
     # 3rd party import
     import numpy as np
     from scipy import stats
@@ -175,15 +178,16 @@ def image_flattening(ima, **kwargs):
 
     Arguments :
         ima (nparray): image to process
-        **kwargs: kwargs["method_flat"]
-                  kwargs["sigma"]
-                  kwargs["kx"]
-                  kwargs["ky"]
+        **kwargs: kwargs["method_flat"] gauss , poy
+                  kwargs["sigma"]  if method == "gauss" 
+                  kwargs["kx"] if method == "poly" 
+                  kwargs["ky"] if method == "poly" 
 
 
     Returns:
         ima (nparray): corrected image
     """
+    
     if "method_flat" in list(kwargs.keys()):
         method_type = kwargs["method_flat"]
     else:
@@ -220,10 +224,11 @@ def gaussian_flattening(im, sigma):
     '''
     Image flattening
     '''
+    
     # 3rd party imports
     from scipy.ndimage import gaussian_filter
 
-    im_flat = im/gaussian_filter(im, sigma=sigma)
+    im_flat = im - gaussian_filter(im, sigma=sigma)
     return im_flat
 
 def poly_flattening(im, kx, ky, order=None):
@@ -281,36 +286,52 @@ def polyfit2d(x, y, z, kx, ky, order):
     return coeff.reshape(kx+1,ky+1)
 
 def poly2Dreco(x,y, c):
+
+    # 3rd party import
     import numpy as np
     return np.polynomial.polynomial.polygrid2d(x,y,c).T
 
 
-def analyse_morphologique(img):
+def analyse_morphologique(img_bin, img):
 
     '''
     find the features in the image
     Arguments:
-        img (ndarray): image to analyze
-        path (string): absolute path of the excel file containing the dataframe df (see returns)
-                       optional (default=None no storage)
+        img_bin (2D array): binarized image to analyze
+        img (2D array):  image before binarization
+        
     Returns:
-        df (dataframe): index|'x'|'long_x'| 'y'|'long_y'| 'size'
+        df (dataframe): index|'x'|'long_x'| 'y'|'long_y'| 'size'|'depth'
     '''
-
+    
+    # 3rd party import
     import numpy as np
     from scipy.ndimage.measurements import label
     import pandas as pd
 
-    labeled_array, num_features = label(img,[[0,1,0], [1,1,1], [0,1,0]])
+    def height(i):
+        
+        '''
+        compute the maximum hegth of feature with label i
+        '''
+        result = np.where(labeled_array == i)
+        return min([img[x] for x in zip(result[0],result[1] )])
+
+    labeled_array, num_features = label(img_bin,[[0,1,0], [1,1,1], [0,1,0]])
 
     morpho = {}
 
     for i in range(1,np.max(labeled_array)+1):
         x,y = np.where(labeled_array==i)
-        morpho[i] = [ int(np.mean(x)), max(x)-min(x)+1, int(np.mean(y)), max(y)-min(y)+1, np.sum(labeled_array==i)]
+        morpho[i] = [ int(np.mean(x)), 
+                      max(x)-min(x)+1, 
+                      int(np.mean(y)),
+                      max(y)-min(y)+1,
+                      np.sum(labeled_array==i),
+                      height(i)]
 
     df = pd.DataFrame.from_dict(morpho, orient='index',
-                           columns=['x','long_x', 'y','long_y', 'size'])
+                           columns=['x','long_x', 'y','long_y', 'size', 'height'])
 
     return df
 
@@ -325,7 +346,8 @@ def Otsu_tresholding(im,Ostu_corr=1):
     Returns:
         im_bin (ndarray) : binarized image
     '''
-
+    
+    # 3rd party import
     from skimage import filters
     import numpy as np
 
@@ -334,14 +356,28 @@ def Otsu_tresholding(im,Ostu_corr=1):
     return im_bin
 
 def top_hat_flattening(im,struct_elmt_size):
-    ''' mise à plat de l image en appliquant une transformation top hat à chacune des lignes de l image im'''
+
+    ''' 
+    mise à plat de l image en appliquant une transformation top hat à chacune
+    des lignes de l image im
+    
+    Arguments:
+        im (2D array): image to process
+        struct_elmt_size (int): length of the structure element (must be larger then
+            the larger length of the feature of interest)
+    Returns:
+        Ip (2D array) : processed image
+    '''
+    
+    # 3rd party import
     from scipy.ndimage import white_tophat
+    import numpy as np 
+    
     (mx,my)=np.shape(im)
     Ip=[]
     for ii in range(mx):
         Ip.append(white_tophat(im[ii,:], None, np.repeat([1], struct_elmt_size)))
     Ip=np.array(Ip).reshape((mx,my))
-    Ip=255*Ip/np.max(np.max(Ip))
 
     return Ip
 
@@ -352,6 +388,8 @@ def effective_erea(df,n_row, n_col):
     return eff_erea
 
 def convert(data):
+
+    # 3rd party import
     import numpy as np
     data = data / data.max() #normalizes data in range 0 - 255
     data = 255 * data
@@ -421,16 +459,16 @@ def read_plu_topography(file):
 
     # Area 3 not used
     pos += struct.calcsize(fmt)
-    print(pos,len(data))
     fmt = 'i'
     offset = struct.unpack(fmt, data[pos:pos+struct.calcsize(fmt)])
 
     pos += offset[0]
 
     # area 4 work in progress (missing information)
-    return N, M, confocal_img, rgb, date
+    return N, M, confocal_img, rgb
 
 def fill_gap(data):
+
     '''
     fill the missing value (1000001) of the confocal image using a linear interpolation method
 
@@ -439,7 +477,10 @@ def fill_gap(data):
     Returns:
         data (2D nparray of floats): confocal image with interpolated values
     '''
+    
+    # 3rd party import
     import numpy as np
+    
     shape = data.shape
     data = data.flatten()
     mask = np.array([True if x==1000001 else False for x in data ])
