@@ -11,9 +11,9 @@ def image_processing(param, analyse_morpho=True):
     from pathlib import Path
     import pandas as pd
     
-    # Inernal import
-    from ./image_features_extract import read_image,gaussian_flattening
-    from ./image_features_extract import xRemoveSpriesHorizontal, Otsu_tresholding
+    # Internal import
+    from .image_features_extract import read_image,gaussian_flattening
+    from .image_features_extract import xRemoveSpriesHorizontal, Otsu_tresholding
 
     # lecture de l'image
     im_brute, n_row, n_col = read_image(param["repertoire"] / param["file"])
